::: ropt.plugins.optimizer

::: ropt.plugins.optimizer.base
    options:
        members:
            - Optimizer
            - OptimizerCallback
            - OptimizerPlugin

::: ropt.plugins.optimizer.utils
